@@ -32,9 +32,9 @@ has options         => sub {
   };
 };
 has [qw(password username)] => '';
-has pubsub                  => sub { Mojo::Pg::PubSub->new(pg => shift) };
+has pubsub => sub { Mojo::Pg::PubSub->new(pg => shift) };
 
-our $VERSION = '4.16';
+our $VERSION = '4.17';
 
 sub db { $_[0]->database_class->new(dbh => $_[0]->_prepare, pg => $_[0]) }
 
@@ -53,8 +53,8 @@ sub from_string {
   # Connection information
   my $db  = $url->path->parts->[0];
   my $dsn = defined $db ? "dbi:Pg:dbname=$db" : 'dbi:Pg:';
-  if (my $host = $url->host) { $dsn .= ";host=$host" }
-  if (my $port = $url->port) { $dsn .= ";port=$port" }
+  if (my $host = $url->host)                  { $dsn .= ";host=$host" }
+  if (my $port = $url->port)                  { $dsn .= ";port=$port" }
   if (defined(my $username = $url->username)) { $self->username($username) }
   if (defined(my $password = $url->password)) { $self->password($password) }
 
@@ -79,9 +79,7 @@ sub _dequeue {
   # Fork-safety
   delete @$self{qw(pid queue)} unless ($self->{pid} //= $$) eq $$;
 
-  while (my $dbh = shift @{$self->{queue} || []}) {
-    return $dbh if $dbh->{Active};
-  }
+  while (my $dbh = shift @{$self->{queue} || []}) { return $dbh if $dbh->ping }
   my $dbh = DBI->connect(map { $self->$_ } qw(dsn username password options));
 
   # Search path
@@ -100,10 +98,8 @@ sub _enqueue {
 
   if (my $parent = $self->parent) { return $parent->_enqueue($dbh) }
 
-  # Async connections need to be checked more carefully
   my $queue = $self->{queue} ||= [];
-  $dbh->{private_mojo_async} = undef if my $async = $dbh->{private_mojo_async};
-  push @$queue, $dbh if $dbh->{Active} && ($async ? $dbh->ping : 1);
+  push @$queue, $dbh if $dbh->{Active};
   shift @$queue while @$queue > $self->max_connections;
 }
 
