@@ -172,8 +172,8 @@ sub _table {
   my $sep = $self->{name_sep} // '';
   for my $join (@join) {
     puke 'join must be in the form [$table, $fk => $pk]' if @$join < 3;
-    my $type = @$join % 2 == 0 ? shift @$join : '';
-    my ($name, $fk, $pk, @morekeys) = @$join;
+    my ($type, $name, $fk, $pk, @morekeys)
+      = @$join % 2 == 0 ? @$join : ('', @$join);
     $table
       .= $self->_sqlcase($type =~ /^-(.+)$/ ? " $1 join " : ' join ')
       . $self->_quote($name)
@@ -227,7 +227,7 @@ op to encode JSON from Perl data structures.
 =head2 ON CONFLICT
 
 The C<on_conflict> option can be used to generate C<INSERT> queries with
-C<ON CONFLICT> clauses. So far C<undef> to pass C<DO NOTHING>, array references
+C<ON CONFLICT> clauses. So far, C<undef> to pass C<DO NOTHING>, array references
 to pass C<DO UPDATE> with conflict targets and a C<SET> expression, scalar
 references to pass literal SQL and array reference references to pass literal
 SQL with bind values are supported.
@@ -323,8 +323,8 @@ with C<LIMIT> and C<OFFSET> clauses.
 =head2 GROUP BY
 
 The C<group_by> option can be used to generate C<SELECT> queries with
-C<GROUP BY> clauses. So far array references to pass a list of fields and scalar
-references to pass literal SQL are supported.
+C<GROUP BY> clauses. So far, array references to pass a list of fields and
+scalar references to pass literal SQL are supported.
 
   # "select * from some_table group by foo, bar"
   $abstract->select('some_table', '*', undef, {group_by => ['foo', 'bar']});
@@ -343,7 +343,7 @@ clauses, which takes the same values as the C<$where> argument.
 =head2 FOR
 
 The C<for> option can be used to generate C<SELECT> queries with C<FOR> clauses.
-So far the scalar value C<update> to pass C<UPDATE> and scalar references to
+So far, the scalar value C<update> to pass C<UPDATE> and scalar references to
 pass literal SQL are supported.
 
   # "select * from some_table for update"
